"""
Generated class for ObservationDefinition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class QualifiedValue(FhirBaseModel):
    """A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept context: Context qualifier for the set of qualified values
    :param CodeableConcept appliesTo: Targetted population for the set of qualified values
    :param str gender: male | female | other | unknown
    :param Range age: Applicable age range for the set of qualified values
    :param Range gestationalAge: Applicable gestational age range for the set of qualified values
    :param str condition: Condition associated with the set of qualified values
    :param str rangeCategory: reference | critical | absolute
    :param Range range: The range for continuous or ordinal observations
    :param str validCodedValueSet: Value set of valid coded values as part of this set of qualified values
    :param str normalCodedValueSet: Value set of normal coded values as part of this set of qualified values
    :param str abnormalCodedValueSet: Value set of abnormal coded values as part of this set of qualified values
    :param str criticalCodedValueSet: Value set of critical coded values as part of this set of qualified values
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "context": {"class_name": "CodeableConcept", "is_contained": False},
        "appliesTo": {"class_name": "CodeableConcept", "is_contained": False},
        "age": {"class_name": "Range", "is_contained": False},
        "gestationalAge": {"class_name": "Range", "is_contained": False},
        "range": {"class_name": "Range", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        context: "CodeableConcept" = None,
        appliesTo: list["CodeableConcept"] = None,
        gender: "str" = None,
        age: "Range" = None,
        gestationalAge: "Range" = None,
        condition: "str" = None,
        rangeCategory: "str" = None,
        range: "Range" = None,
        validCodedValueSet: "str" = None,
        normalCodedValueSet: "str" = None,
        abnormalCodedValueSet: "str" = None,
        criticalCodedValueSet: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.context = context
        self.appliesTo = appliesTo or []
        self.gender = gender
        self.age = age
        self.gestationalAge = gestationalAge
        self.condition = condition
        self.rangeCategory = rangeCategory
        self.range = range
        self.validCodedValueSet = validCodedValueSet
        self.normalCodedValueSet = normalCodedValueSet
        self.abnormalCodedValueSet = abnormalCodedValueSet
        self.criticalCodedValueSet = criticalCodedValueSet

    @classmethod
    def from_dict(cls, data: dict) -> "ObservationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ObservationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Component(FhirBaseModel):
    """Some observations have multiple component observations, expressed as separate code value pairs.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Type of observation
    :param str permittedDataType: Quantity | CodeableConcept | string | boolean | integer | Range | Ratio | SampledData | time | dateTime | Period
    :param Coding permittedUnit: Unit for quantitative results
    :param QualifiedValue qualifiedValue: Set of qualified values for observation results
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "permittedUnit": {"class_name": "Coding", "is_contained": False},
        "qualifiedValue": {"class_name": "QualifiedValue", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        permittedDataType: list["str"] = None,
        permittedUnit: list["Coding"] = None,
        qualifiedValue: list["QualifiedValue"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.permittedDataType = permittedDataType or []
        self.permittedUnit = permittedUnit or []
        self.qualifiedValue = qualifiedValue or []

    @classmethod
    def from_dict(cls, data: dict) -> "ObservationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ObservationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ObservationDefinition(DomainResource):
    """Set of definitional characteristics for a kind of observation or measurement produced or consumed by an orderable health care service.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Logical canonical URL to reference this ObservationDefinition (globally unique)
    :param Identifier identifier: Business identifier of the ObservationDefinition
    :param str version: Business version of the ObservationDefinition
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this ObservationDefinition (computer friendly)
    :param str title: Name for this ObservationDefinition (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: If for testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: The name of the individual or organization that published the ObservationDefinition
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the ObservationDefinition
    :param UsageContext useContext: Content intends to support these contexts
    :param CodeableConcept jurisdiction: Intended jurisdiction for this ObservationDefinition (if applicable)
    :param str purpose: Why this ObservationDefinition is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param str approvalDate: When ObservationDefinition was approved by publisher
    :param str lastReviewDate: Date on which the asset content was last reviewed by the publisher
    :param Period effectivePeriod: The effective date range for the ObservationDefinition
    :param str derivedFromCanonical: Based on FHIR definition of another observation
    :param str derivedFromUri: Based on external definition
    :param CodeableConcept subject: Type of subject for the defined observation
    :param CodeableConcept performerType: Desired kind of performer for such kind of observation
    :param CodeableConcept category: General type of observation
    :param CodeableConcept code: Type of observation
    :param str permittedDataType: Quantity | CodeableConcept | string | boolean | integer | Range | Ratio | SampledData | time | dateTime | Period
    :param bool multipleResultsAllowed: Multiple results allowed for conforming observations
    :param CodeableConcept bodySite: Body part to be observed
    :param CodeableConcept method: Method used to produce the observation
    :param Reference specimen: Kind of specimen used by this type of observation
    :param Reference device: Measurement device or model of device
    :param str preferredReportName: The preferred name to be used when reporting the observation results
    :param Coding permittedUnit: Unit for quantitative results
    :param QualifiedValue qualifiedValue: Set of qualified values for observation results
    :param Reference hasMember: Definitions of related resources belonging to this kind of observation group
    :param Component component: Component results
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "subject": {"class_name": "CodeableConcept", "is_contained": False},
        "performerType": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "specimen": {"class_name": "Reference", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "permittedUnit": {"class_name": "Coding", "is_contained": False},
        "qualifiedValue": {"class_name": "QualifiedValue", "is_contained": True},
        "hasMember": {"class_name": "Reference", "is_contained": False},
        "component": {"class_name": "Component", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: "Identifier" = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        derivedFromCanonical: list["str"] = None,
        derivedFromUri: list["str"] = None,
        subject: list["CodeableConcept"] = None,
        performerType: "CodeableConcept" = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        permittedDataType: list["str"] = None,
        multipleResultsAllowed: "bool" = None,
        bodySite: "CodeableConcept" = None,
        method: "CodeableConcept" = None,
        specimen: list["Reference"] = None,
        device: list["Reference"] = None,
        preferredReportName: "str" = None,
        permittedUnit: list["Coding"] = None,
        qualifiedValue: list["QualifiedValue"] = None,
        hasMember: list["Reference"] = None,
        component: list["Component"] = None,
    ):

        self.resourceType = "ObservationDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.derivedFromCanonical = derivedFromCanonical or []
        self.derivedFromUri = derivedFromUri or []
        self.subject = subject or []
        self.performerType = performerType
        self.category = category or []
        self.code = code
        self.permittedDataType = permittedDataType or []
        self.multipleResultsAllowed = multipleResultsAllowed
        self.bodySite = bodySite
        self.method = method
        self.specimen = specimen or []
        self.device = device or []
        self.preferredReportName = preferredReportName
        self.permittedUnit = permittedUnit or []
        self.qualifiedValue = qualifiedValue or []
        self.hasMember = hasMember or []
        self.component = component or []

    @classmethod
    def from_dict(cls, data: dict) -> "ObservationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ObservationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for FormularyItem. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Resource import *


class FormularyItem(DomainResource):
    """This resource describes a product or service that is available through a program and includes the conditions and constraints of availability.  All of the information in this resource is specific to the inclusion of the item in the formulary and is not inherent to the item itself.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for this formulary item
    :param CodeableConcept code: Codes that identify this formulary item
    :param str status: active | entered-in-error | inactive
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        code: "CodeableConcept" = None,
        status: "str" = None,
    ):

        self.resourceType = "FormularyItem"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.code = code
        self.status = status

    @classmethod
    def from_dict(cls, data: dict) -> "FormularyItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "FormularyItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ProdCharacteristic. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.Attachment import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Quantity import *


class ProdCharacteristic(FhirBaseModel):
    """Base StructureDefinition for ProdCharacteristic Type: The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity height: Where applicable, the height can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used
    :param Quantity width: Where applicable, the width can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used
    :param Quantity depth: Where applicable, the depth can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used
    :param Quantity weight: Where applicable, the weight can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used
    :param Quantity nominalVolume: Where applicable, the nominal volume can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used
    :param Quantity externalDiameter: Where applicable, the external diameter can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used
    :param str shape: Where applicable, the shape can be specified An appropriate controlled vocabulary shall be used The term and the term identifier shall be used
    :param str color: Where applicable, the color can be specified An appropriate controlled vocabulary shall be used The term and the term identifier shall be used
    :param str imprint: Where applicable, the imprint can be specified as text
    :param Attachment image: Where applicable, the image can be provided The format of the image attachment shall be specified by regional implementations
    :param CodeableConcept scoring: Where applicable, the scoring can be specified An appropriate controlled vocabulary shall be used The term and the term identifier shall be used
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "height": {"class_name": "Quantity", "is_contained": False},
        "width": {"class_name": "Quantity", "is_contained": False},
        "depth": {"class_name": "Quantity", "is_contained": False},
        "weight": {"class_name": "Quantity", "is_contained": False},
        "nominalVolume": {"class_name": "Quantity", "is_contained": False},
        "externalDiameter": {"class_name": "Quantity", "is_contained": False},
        "image": {"class_name": "Attachment", "is_contained": False},
        "scoring": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        height: "Quantity" = None,
        width: "Quantity" = None,
        depth: "Quantity" = None,
        weight: "Quantity" = None,
        nominalVolume: "Quantity" = None,
        externalDiameter: "Quantity" = None,
        shape: "str" = None,
        color: list["str"] = None,
        imprint: list["str"] = None,
        image: list["Attachment"] = None,
        scoring: "CodeableConcept" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.height = height
        self.width = width
        self.depth = depth
        self.weight = weight
        self.nominalVolume = nominalVolume
        self.externalDiameter = externalDiameter
        self.shape = shape
        self.color = color or []
        self.imprint = imprint or []
        self.image = image or []
        self.scoring = scoring

    @classmethod
    def from_dict(cls, data: dict) -> "ProdCharacteristic":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ProdCharacteristic":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for PractitionerRole. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Availability import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.ExtendedContactDetail import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class PractitionerRole(DomainResource):
    """A specific set of Roles/Locations/specialties/services that a practitioner may perform, or has performed at an organization during a period of time.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifiers for a role/location
    :param bool active: Whether this practitioner role record is in active use
    :param Period period: The period during which the practitioner is authorized to perform in these role(s)
    :param Reference practitioner: Practitioner that provides services for the organization
    :param Reference organization: Organization where the roles are available
    :param CodeableConcept code: Roles which this practitioner may perform
    :param CodeableConcept specialty: Specific specialty of the practitioner
    :param Reference location: Location(s) where the practitioner provides care
    :param Reference healthcareService: Healthcare services provided for this role's Organization/Location(s)
    :param ExtendedContactDetail contact: Official contact details relating to this PractitionerRole
    :param CodeableConcept characteristic: Collection of characteristics (attributes)
    :param CodeableConcept communication: A language the practitioner (in this role) can use in patient communication
    :param Availability availability: Times the Practitioner is available at this location and/or healthcare service (including exceptions)
    :param Reference endpoint: Endpoints for interacting with the practitioner in this role
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "practitioner": {"class_name": "Reference", "is_contained": False},
        "organization": {"class_name": "Reference", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "specialty": {"class_name": "CodeableConcept", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "healthcareService": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "ExtendedContactDetail", "is_contained": False},
        "characteristic": {"class_name": "CodeableConcept", "is_contained": False},
        "communication": {"class_name": "CodeableConcept", "is_contained": False},
        "availability": {"class_name": "Availability", "is_contained": False},
        "endpoint": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        period: "Period" = None,
        practitioner: "Reference" = None,
        organization: "Reference" = None,
        code: list["CodeableConcept"] = None,
        specialty: list["CodeableConcept"] = None,
        location: list["Reference"] = None,
        healthcareService: list["Reference"] = None,
        contact: list["ExtendedContactDetail"] = None,
        characteristic: list["CodeableConcept"] = None,
        communication: list["CodeableConcept"] = None,
        availability: list["Availability"] = None,
        endpoint: list["Reference"] = None,
    ):

        self.resourceType = "PractitionerRole"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.active = active
        self.period = period
        self.practitioner = practitioner
        self.organization = organization
        self.code = code or []
        self.specialty = specialty or []
        self.location = location or []
        self.healthcareService = healthcareService or []
        self.contact = contact or []
        self.characteristic = characteristic or []
        self.communication = communication or []
        self.availability = availability or []
        self.endpoint = endpoint or []

    @classmethod
    def from_dict(cls, data: dict) -> "PractitionerRole":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PractitionerRole":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for OrganizationAffiliation. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.ExtendedContactDetail import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class OrganizationAffiliation(DomainResource):
    """Defines an affiliation/assotiation/relationship between 2 distinct organizations, that is not a part-of relationship/sub-division relationship.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifiers that are specific to this role
    :param bool active: Whether this organization affiliation record is in active use
    :param Period period: The period during which the participatingOrganization is affiliated with the primary organization
    :param Reference organization: Organization where the role is available
    :param Reference participatingOrganization: Organization that provides/performs the role (e.g. providing services or is a member of)
    :param Reference network: The network in which the participatingOrganization provides the role's services (if defined) at the indicated locations (if defined)
    :param CodeableConcept code: Definition of the role the participatingOrganization plays
    :param CodeableConcept specialty: Specific specialty of the participatingOrganization in the context of the role
    :param Reference location: The location(s) at which the role occurs
    :param Reference healthcareService: Healthcare services provided through the role
    :param ExtendedContactDetail contact: Official contact details at the participatingOrganization relevant to this Affiliation
    :param Reference endpoint: Technical endpoints providing access to services operated for this role
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "organization": {"class_name": "Reference", "is_contained": False},
        "participatingOrganization": {"class_name": "Reference", "is_contained": False},
        "network": {"class_name": "Reference", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "specialty": {"class_name": "CodeableConcept", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "healthcareService": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "ExtendedContactDetail", "is_contained": False},
        "endpoint": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        period: "Period" = None,
        organization: "Reference" = None,
        participatingOrganization: "Reference" = None,
        network: list["Reference"] = None,
        code: list["CodeableConcept"] = None,
        specialty: list["CodeableConcept"] = None,
        location: list["Reference"] = None,
        healthcareService: list["Reference"] = None,
        contact: list["ExtendedContactDetail"] = None,
        endpoint: list["Reference"] = None,
    ):

        self.resourceType = "OrganizationAffiliation"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.active = active
        self.period = period
        self.organization = organization
        self.participatingOrganization = participatingOrganization
        self.network = network or []
        self.code = code or []
        self.specialty = specialty or []
        self.location = location or []
        self.healthcareService = healthcareService or []
        self.contact = contact or []
        self.endpoint = endpoint or []

    @classmethod
    def from_dict(cls, data: dict) -> "OrganizationAffiliation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "OrganizationAffiliation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for AuditEvent. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Network(FhirBaseModel):
    """Logical network location for application activity, if the activity has a network location.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str address: Identifier for the network access point of the user device
    :param str type: The type of network access point
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        address: "str" = None,
        type: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.address = address
        self.type = type

    @classmethod
    def from_dict(cls, data: dict) -> "AuditEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AuditEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Agent(FhirBaseModel):
    """An actor taking an active role in the event or activity that is logged.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: How agent participated
    :param CodeableConcept role: Agent role in the event
    :param Reference who: Identifier of who
    :param str altId: Alternative User identity
    :param str name: Human friendly name for the agent
    :param bool requestor: Whether user is initiator
    :param Reference location: Where
    :param str policy: Policy that authorized event
    :param Coding media: Type of media
    :param Network network: Logical network location for application activity
    :param CodeableConcept purposeOfUse: Reason given for this user
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "who": {"class_name": "Reference", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "media": {"class_name": "Coding", "is_contained": False},
        "network": {"class_name": "Network", "is_contained": True},
        "purposeOfUse": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        role: list["CodeableConcept"] = None,
        who: "Reference" = None,
        altId: "str" = None,
        name: "str" = None,
        requestor: "bool" = None,
        location: "Reference" = None,
        policy: list["str"] = None,
        media: "Coding" = None,
        network: "Network" = None,
        purposeOfUse: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.role = role or []
        self.who = who
        self.altId = altId
        self.name = name
        self.requestor = requestor
        self.location = location
        self.policy = policy or []
        self.media = media
        self.network = network
        self.purposeOfUse = purposeOfUse or []

    @classmethod
    def from_dict(cls, data: dict) -> "AuditEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AuditEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Source(FhirBaseModel):
    """The system that is reporting the event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str site: Logical source location within the enterprise
    :param Reference observer: The identity of source detecting the event
    :param Coding type: The type of source where event originated
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "observer": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        site: "str" = None,
        observer: "Reference" = None,
        type: list["Coding"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.site = site
        self.observer = observer
        self.type = type or []

    @classmethod
    def from_dict(cls, data: dict) -> "AuditEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AuditEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Detail(FhirBaseModel):
    """Tagged value pairs for conveying additional information about the entity.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: Name of the property
    :param str valueString: Property value
    :param str valueBase64Binary: Property value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        valueString: "str" = None,
        valueBase64Binary: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueString = valueString
        self.valueBase64Binary = valueBase64Binary

    @classmethod
    def from_dict(cls, data: dict) -> "AuditEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AuditEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Entity(FhirBaseModel):
    """Specific instances of data or objects that have been accessed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference what: Specific instance of resource
    :param Coding type: Type of entity involved
    :param Coding role: What role the entity played
    :param Coding lifecycle: Life-cycle stage for the entity
    :param Coding securityLabel: Security labels on the entity
    :param str name: Descriptor for entity
    :param str description: Descriptive text
    :param str query: Query parameters
    :param Detail detail: Additional Information about the entity
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "what": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "Coding", "is_contained": False},
        "role": {"class_name": "Coding", "is_contained": False},
        "lifecycle": {"class_name": "Coding", "is_contained": False},
        "securityLabel": {"class_name": "Coding", "is_contained": False},
        "detail": {"class_name": "Detail", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        what: "Reference" = None,
        type: "Coding" = None,
        role: "Coding" = None,
        lifecycle: "Coding" = None,
        securityLabel: list["Coding"] = None,
        name: "str" = None,
        description: "str" = None,
        query: "str" = None,
        detail: list["Detail"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.what = what
        self.type = type
        self.role = role
        self.lifecycle = lifecycle
        self.securityLabel = securityLabel or []
        self.name = name
        self.description = description
        self.query = query
        self.detail = detail or []

    @classmethod
    def from_dict(cls, data: dict) -> "AuditEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AuditEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AuditEvent(DomainResource):
    """A record of an event made for purposes of maintaining a security log. Typical uses include detection of intrusion attempts and monitoring for inappropriate usage.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Coding type: Type/identifier of event
    :param Coding subtype: More specific type/id for the event
    :param str action: Type of action performed during the event
    :param Period period: When the activity occurred
    :param str recorded: Time when the event was recorded
    :param str outcome: Whether the event succeeded or failed
    :param str outcomeDesc: Description of the event outcome
    :param CodeableConcept purposeOfEvent: The purposeOfUse of the event
    :param Agent agent: Actor involved in the event
    :param Source source: Audit Event Reporter
    :param Entity entity: Data or objects used
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "Coding", "is_contained": False},
        "subtype": {"class_name": "Coding", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "purposeOfEvent": {"class_name": "CodeableConcept", "is_contained": False},
        "agent": {"class_name": "Agent", "is_contained": True},
        "source": {"class_name": "Source", "is_contained": True},
        "entity": {"class_name": "Entity", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "Coding" = None,
        subtype: list["Coding"] = None,
        action: "str" = None,
        period: "Period" = None,
        recorded: "str" = None,
        outcome: "str" = None,
        outcomeDesc: "str" = None,
        purposeOfEvent: list["CodeableConcept"] = None,
        agent: list["Agent"] = None,
        source: "Source" = None,
        entity: list["Entity"] = None,
    ):

        self.resourceType = "AuditEvent"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.subtype = subtype or []
        self.action = action
        self.period = period
        self.recorded = recorded
        self.outcome = outcome
        self.outcomeDesc = outcomeDesc
        self.purposeOfEvent = purposeOfEvent or []
        self.agent = agent or []
        self.source = source
        self.entity = entity or []

    @classmethod
    def from_dict(cls, data: dict) -> "AuditEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AuditEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for OperationOutcome. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Resource import *


class Issue(FhirBaseModel):
    """An error, warning, or information message that results from a system action.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str severity: fatal | error | warning | information
    :param str code: Error or warning code
    :param CodeableConcept details: Additional details about the error
    :param str diagnostics: Additional diagnostic information about the issue
    :param str location: Deprecated: Path of element(s) related to issue
    :param str expression: FHIRPath of element(s) related to issue
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "details": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        severity: "str" = None,
        code: "str" = None,
        details: "CodeableConcept" = None,
        diagnostics: "str" = None,
        location: list["str"] = None,
        expression: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.severity = severity
        self.code = code
        self.details = details
        self.diagnostics = diagnostics
        self.location = location or []
        self.expression = expression or []

    @classmethod
    def from_dict(cls, data: dict) -> "OperationOutcome":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "OperationOutcome":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class OperationOutcome(DomainResource):
    """A collection of error, warning, or information messages that result from a system action.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Issue issue: A single issue associated with the action
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "issue": {"class_name": "Issue", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        issue: list["Issue"] = None,
    ):

        self.resourceType = "OperationOutcome"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.issue = issue or []

    @classmethod
    def from_dict(cls, data: dict) -> "OperationOutcome":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "OperationOutcome":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicationAdministration. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Ratio import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class Performer(FhirBaseModel):
    """Indicates who or what performed the medication administration and how they were involved.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: Type of performance
    :param Reference actor: Who performed the medication administration
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationAdministration":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationAdministration":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Dosage(FhirBaseModel):
    """Describes the medication dosage information details e.g. dose, rate, site, route, etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str text: Free text dosage instructions e.g. SIG
    :param CodeableConcept site: Body site administered to
    :param CodeableConcept route: Path of substance into body
    :param CodeableConcept method: How drug was administered
    :param Quantity dose: Amount of medication per dose
    :param Ratio rateRatio: Dose quantity per unit of time
    :param Quantity rateQuantity: Dose quantity per unit of time
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "site": {"class_name": "CodeableConcept", "is_contained": False},
        "route": {"class_name": "CodeableConcept", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "dose": {"class_name": "Quantity", "is_contained": False},
        "rateRatio": {"class_name": "Ratio", "is_contained": False},
        "rateQuantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        text: "str" = None,
        site: "CodeableConcept" = None,
        route: "CodeableConcept" = None,
        method: "CodeableConcept" = None,
        dose: "Quantity" = None,
        rateRatio: "Ratio" = None,
        rateQuantity: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.text = text
        self.site = site
        self.route = route
        self.method = method
        self.dose = dose
        self.rateRatio = rateRatio
        self.rateQuantity = rateQuantity

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationAdministration":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationAdministration":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicationAdministration(DomainResource):
    """Describes the event of a patient consuming or otherwise being administered a medication.  This may be as simple as swallowing a tablet or it may be a long running infusion.  Related resources tie this event to the authorizing prescription, and the specific encounter between patient and health care practitioner.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External identifier
    :param str instantiates: Instantiates protocol or definition
    :param Reference partOf: Part of referenced event
    :param str status: in-progress | not-done | on-hold | completed | entered-in-error | stopped | unknown
    :param CodeableConcept statusReason: Reason administration not performed
    :param CodeableConcept category: Type of medication usage
    :param CodeableConcept medicationCodeableConcept: What was administered
    :param Reference medicationReference: What was administered
    :param Reference subject: Who received medication
    :param Reference context: Encounter or Episode of Care administered as part of
    :param Reference supportingInformation: Additional information to support administration
    :param str effectiveDateTime: Start and end time of administration
    :param Period effectivePeriod: Start and end time of administration
    :param Performer performer: Who performed the medication administration and what they did
    :param CodeableConcept reasonCode: Reason administration performed
    :param Reference reasonReference: Condition or observation that supports why the medication was administered
    :param Reference request: Request administration performed against
    :param Reference device: Device used to administer
    :param Annotation note: Information about the administration
    :param Dosage dosage: Details of how medication was taken
    :param Reference eventHistory: A list of events of interest in the lifecycle
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "medicationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "medicationReference": {"class_name": "Reference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "context": {"class_name": "Reference", "is_contained": False},
        "supportingInformation": {"class_name": "Reference", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "performer": {"class_name": "Performer", "is_contained": True},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "request": {"class_name": "Reference", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "dosage": {"class_name": "Dosage", "is_contained": True},
        "eventHistory": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiates: list["str"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        statusReason: list["CodeableConcept"] = None,
        category: "CodeableConcept" = None,
        medicationCodeableConcept: "CodeableConcept" = None,
        medicationReference: "Reference" = None,
        subject: "Reference" = None,
        context: "Reference" = None,
        supportingInformation: list["Reference"] = None,
        effectiveDateTime: "str" = None,
        effectivePeriod: "Period" = None,
        performer: list["Performer"] = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        request: "Reference" = None,
        device: list["Reference"] = None,
        note: list["Annotation"] = None,
        dosage: "Dosage" = None,
        eventHistory: list["Reference"] = None,
    ):

        self.resourceType = "MedicationAdministration"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiates = instantiates or []
        self.partOf = partOf or []
        self.status = status
        self.statusReason = statusReason or []
        self.category = category
        self.medicationCodeableConcept = medicationCodeableConcept
        self.medicationReference = medicationReference
        self.subject = subject
        self.context = context
        self.supportingInformation = supportingInformation or []
        self.effectiveDateTime = effectiveDateTime
        self.effectivePeriod = effectivePeriod
        self.performer = performer or []
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.request = request
        self.device = device or []
        self.note = note or []
        self.dosage = dosage
        self.eventHistory = eventHistory or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationAdministration":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationAdministration":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for NutritionIntake. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.Timing import *


class ConsumedItem(FhirBaseModel):
    """What food or fluid product or item was consumed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The type of food or fluid product
    :param CodeableReference nutritionProduct: Code that identifies the food or fluid product that was consumed
    :param Timing schedule: Scheduled frequency of consumption
    :param Quantity amount: Quantity of the specified food
    :param Quantity rate: Rate at which enteral feeding was administered
    :param bool notConsumed: Flag to indicate if the food or fluid item was refused or otherwise not consumed
    :param CodeableConcept notConsumedReason: Reason food or fluid was not consumed
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "nutritionProduct": {"class_name": "CodeableReference", "is_contained": False},
        "schedule": {"class_name": "Timing", "is_contained": False},
        "amount": {"class_name": "Quantity", "is_contained": False},
        "rate": {"class_name": "Quantity", "is_contained": False},
        "notConsumedReason": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        nutritionProduct: "CodeableReference" = None,
        schedule: "Timing" = None,
        amount: "Quantity" = None,
        rate: "Quantity" = None,
        notConsumed: "bool" = None,
        notConsumedReason: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.nutritionProduct = nutritionProduct
        self.schedule = schedule
        self.amount = amount
        self.rate = rate
        self.notConsumed = notConsumed
        self.notConsumedReason = notConsumedReason

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionIntake":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionIntake":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class IngredientLabel(FhirBaseModel):
    """Total nutrient amounts for the whole meal, product, serving, etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference nutrient: Total nutrient consumed
    :param Quantity amount: Total amount of nutrient consumed
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "nutrient": {"class_name": "CodeableReference", "is_contained": False},
        "amount": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        nutrient: "CodeableReference" = None,
        amount: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.nutrient = nutrient
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionIntake":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionIntake":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Performer(FhirBaseModel):
    """Who performed the intake and how they were involved.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: Type of performer
    :param Reference actor: Who performed the intake
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionIntake":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionIntake":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class NutritionIntake(DomainResource):
    """A record of food or fluid that is being consumed by a patient.  A NutritionIntake may indicate that the patient may be consuming the food or fluid now or has consumed the food or fluid in the past.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay or through an app that tracks food or fluids consumed.   The consumption information may come from sources such as the patient's memory, from a nutrition label,  or from a clinician documenting observed intake.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External identifier
    :param str instantiatesCanonical: Instantiates FHIR protocol or definition
    :param str instantiatesUri: Instantiates external protocol or definition
    :param Reference basedOn: Fulfils plan, proposal or order
    :param Reference partOf: Part of referenced event
    :param str status: preparation | in-progress | not-done | on-hold | stopped | completed | entered-in-error | unknown
    :param CodeableConcept statusReason: Reason for current status
    :param CodeableConcept code: Code representing an overall type of nutrition intake
    :param Reference subject: Who is/was consuming the food or fluid
    :param Reference encounter: Encounter associated with NutritionIntake
    :param str occurrenceDateTime: The date/time or interval when the food or fluid is/was consumed
    :param Period occurrencePeriod: The date/time or interval when the food or fluid is/was consumed
    :param str recorded: When the intake was recorded
    :param bool reportedBoolean: Person or organization that provided the information about the consumption of this food or fluid
    :param Reference reportedReference: Person or organization that provided the information about the consumption of this food or fluid
    :param ConsumedItem consumedItem: What food or fluid product or item was consumed
    :param IngredientLabel ingredientLabel: Total nutrient for the whole meal, product, serving
    :param Performer performer: Who was performed in the intake
    :param Reference location: Where the intake occurred
    :param Reference derivedFrom: Additional supporting information
    :param CodeableReference reason: Reason for why the food or fluid is /was consumed
    :param Annotation note: Further information about the consumption
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "occurrencePeriod": {"class_name": "Period", "is_contained": False},
        "reportedReference": {"class_name": "Reference", "is_contained": False},
        "consumedItem": {"class_name": "ConsumedItem", "is_contained": True},
        "ingredientLabel": {"class_name": "IngredientLabel", "is_contained": True},
        "performer": {"class_name": "Performer", "is_contained": True},
        "location": {"class_name": "Reference", "is_contained": False},
        "derivedFrom": {"class_name": "Reference", "is_contained": False},
        "reason": {"class_name": "CodeableReference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiatesCanonical: list["str"] = None,
        instantiatesUri: list["str"] = None,
        basedOn: list["Reference"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        statusReason: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        occurrenceDateTime: "str" = None,
        occurrencePeriod: "Period" = None,
        recorded: "str" = None,
        reportedBoolean: "bool" = None,
        reportedReference: "Reference" = None,
        consumedItem: list["ConsumedItem"] = None,
        ingredientLabel: list["IngredientLabel"] = None,
        performer: list["Performer"] = None,
        location: "Reference" = None,
        derivedFrom: list["Reference"] = None,
        reason: list["CodeableReference"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "NutritionIntake"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiatesCanonical = instantiatesCanonical or []
        self.instantiatesUri = instantiatesUri or []
        self.basedOn = basedOn or []
        self.partOf = partOf or []
        self.status = status
        self.statusReason = statusReason or []
        self.code = code
        self.subject = subject
        self.encounter = encounter
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrencePeriod = occurrencePeriod
        self.recorded = recorded
        self.reportedBoolean = reportedBoolean
        self.reportedReference = reportedReference
        self.consumedItem = consumedItem or []
        self.ingredientLabel = ingredientLabel or []
        self.performer = performer or []
        self.location = location
        self.derivedFrom = derivedFrom or []
        self.reason = reason or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionIntake":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionIntake":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for PlanDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Age import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.DataRequirement import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Duration import *
from fhirmodels.R4B.Expression import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Range import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.RelatedArtifact import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.Timing import *
from fhirmodels.R4B.TriggerDefinition import *
from fhirmodels.R4B.UsageContext import *


class Target(FhirBaseModel):
    """Indicates what should be done and within what timeframe.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept measure: The parameter whose value is to be tracked
    :param Quantity detailQuantity: The target value to be achieved
    :param Range detailRange: The target value to be achieved
    :param CodeableConcept detailCodeableConcept: The target value to be achieved
    :param Duration due: Reach goal within
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "measure": {"class_name": "CodeableConcept", "is_contained": False},
        "detailQuantity": {"class_name": "Quantity", "is_contained": False},
        "detailRange": {"class_name": "Range", "is_contained": False},
        "detailCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "due": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        measure: "CodeableConcept" = None,
        detailQuantity: "Quantity" = None,
        detailRange: "Range" = None,
        detailCodeableConcept: "CodeableConcept" = None,
        due: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.measure = measure
        self.detailQuantity = detailQuantity
        self.detailRange = detailRange
        self.detailCodeableConcept = detailCodeableConcept
        self.due = due

    @classmethod
    def from_dict(cls, data: dict) -> "PlanDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PlanDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Goal(FhirBaseModel):
    """A goal describes an expected outcome that activities within the plan are intended to achieve. For example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, meeting the acceptance criteria for a test as specified by a quality specification, etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: E.g. Treatment, dietary, behavioral
    :param CodeableConcept description: Code or text describing the goal
    :param CodeableConcept priority: high-priority | medium-priority | low-priority
    :param CodeableConcept start: When goal pursuit begins
    :param CodeableConcept addresses: What does the goal address
    :param RelatedArtifact documentation: Supporting documentation for the goal
    :param Target target: Target outcome for the goal
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "description": {"class_name": "CodeableConcept", "is_contained": False},
        "priority": {"class_name": "CodeableConcept", "is_contained": False},
        "start": {"class_name": "CodeableConcept", "is_contained": False},
        "addresses": {"class_name": "CodeableConcept", "is_contained": False},
        "documentation": {"class_name": "RelatedArtifact", "is_contained": False},
        "target": {"class_name": "Target", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        description: "CodeableConcept" = None,
        priority: "CodeableConcept" = None,
        start: "CodeableConcept" = None,
        addresses: list["CodeableConcept"] = None,
        documentation: list["RelatedArtifact"] = None,
        target: list["Target"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.description = description
        self.priority = priority
        self.start = start
        self.addresses = addresses or []
        self.documentation = documentation or []
        self.target = target or []

    @classmethod
    def from_dict(cls, data: dict) -> "PlanDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PlanDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Condition(FhirBaseModel):
    """An expression that describes applicability criteria or start/stop conditions for the action.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str kind: applicability | start | stop
    :param Expression expression: Boolean-valued expression
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "expression": {"class_name": "Expression", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        kind: "str" = None,
        expression: "Expression" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.kind = kind
        self.expression = expression

    @classmethod
    def from_dict(cls, data: dict) -> "PlanDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PlanDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RelatedAction(FhirBaseModel):
    """A relationship to another action such as "before" or "30-60 minutes after start of".:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str actionId: What action is this related to
    :param str relationship: before-start | before | before-end | concurrent-with-start | concurrent | concurrent-with-end | after-start | after | after-end
    :param Duration offsetDuration: Time offset for the relationship
    :param Range offsetRange: Time offset for the relationship
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "offsetDuration": {"class_name": "Duration", "is_contained": False},
        "offsetRange": {"class_name": "Range", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        actionId: "str" = None,
        relationship: "str" = None,
        offsetDuration: "Duration" = None,
        offsetRange: "Range" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.actionId = actionId
        self.relationship = relationship
        self.offsetDuration = offsetDuration
        self.offsetRange = offsetRange

    @classmethod
    def from_dict(cls, data: dict) -> "PlanDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PlanDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Participant(FhirBaseModel):
    """Indicates who should participate in performing the action described.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: patient | practitioner | related-person | device
    :param CodeableConcept role: E.g. Nurse, Surgeon, Parent
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        role: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.role = role

    @classmethod
    def from_dict(cls, data: dict) -> "PlanDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PlanDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DynamicValue(FhirBaseModel):
    """Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str path: The path to the element to be set dynamically
    :param Expression expression: An expression that provides the dynamic value for the customization
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "expression": {"class_name": "Expression", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        path: "str" = None,
        expression: "Expression" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.path = path
        self.expression = expression

    @classmethod
    def from_dict(cls, data: dict) -> "PlanDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PlanDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Action(FhirBaseModel):
    """An action or group of actions to be taken as part of the plan. For example, in clinical care, an action would be to prescribe a particular indicated medication, or perform a particular test as appropriate. In pharmaceutical quality, an action would be the test that needs to be performed on a drug product as defined in the quality specification.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str prefix: User-visible prefix for the action (e.g. 1. or A.)
    :param str title: User-visible title
    :param str description: Brief description of the action
    :param str textEquivalent: Static text equivalent of the action, used if the dynamic aspects cannot be interpreted by the receiving system
    :param str priority: routine | urgent | asap | stat
    :param CodeableConcept code: Code representing the meaning of the action or sub-actions
    :param CodeableConcept reason: Why the action should be performed
    :param RelatedArtifact documentation: Supporting documentation for the intended performer of the action
    :param str goalId: What goals this action supports
    :param CodeableConcept subjectCodeableConcept: Type of individual the action is focused on
    :param Reference subjectReference: Type of individual the action is focused on
    :param str subjectCanonical: Type of individual the action is focused on
    :param TriggerDefinition trigger: When the action should be triggered
    :param Condition condition: Whether or not the action is applicable
    :param DataRequirement input: Input data requirements
    :param DataRequirement output: Output data definition
    :param RelatedAction relatedAction: Relationship to another action
    :param str timingDateTime: When the action should take place
    :param Age timingAge: When the action should take place
    :param Period timingPeriod: When the action should take place
    :param Duration timingDuration: When the action should take place
    :param Range timingRange: When the action should take place
    :param Timing timingTiming: When the action should take place
    :param Participant participant: Who should participate in the action
    :param CodeableConcept type: create | update | remove | fire-event
    :param str groupingBehavior: visual-group | logical-group | sentence-group
    :param str selectionBehavior: any | all | all-or-none | exactly-one | at-most-one | one-or-more
    :param str requiredBehavior: must | could | must-unless-documented
    :param str precheckBehavior: yes | no
    :param str cardinalityBehavior: single | multiple
    :param str definitionCanonical: Description of the activity to be performed
    :param str definitionUri: Description of the activity to be performed
    :param str transform: Transform to apply the template
    :param DynamicValue dynamicValue: Dynamic aspects of the definition
    :param Action action: A sub-action
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
        "documentation": {"class_name": "RelatedArtifact", "is_contained": False},
        "subjectCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "subjectReference": {"class_name": "Reference", "is_contained": False},
        "trigger": {"class_name": "TriggerDefinition", "is_contained": False},
        "condition": {"class_name": "Condition", "is_contained": True},
        "input": {"class_name": "DataRequirement", "is_contained": False},
        "output": {"class_name": "DataRequirement", "is_contained": False},
        "relatedAction": {"class_name": "RelatedAction", "is_contained": True},
        "timingAge": {"class_name": "Age", "is_contained": False},
        "timingPeriod": {"class_name": "Period", "is_contained": False},
        "timingDuration": {"class_name": "Duration", "is_contained": False},
        "timingRange": {"class_name": "Range", "is_contained": False},
        "timingTiming": {"class_name": "Timing", "is_contained": False},
        "participant": {"class_name": "Participant", "is_contained": True},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "dynamicValue": {"class_name": "DynamicValue", "is_contained": True},
        "action": {"class_name": "Action", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        prefix: "str" = None,
        title: "str" = None,
        description: "str" = None,
        textEquivalent: "str" = None,
        priority: "str" = None,
        code: list["CodeableConcept"] = None,
        reason: list["CodeableConcept"] = None,
        documentation: list["RelatedArtifact"] = None,
        goalId: list["str"] = None,
        subjectCodeableConcept: "CodeableConcept" = None,
        subjectReference: "Reference" = None,
        subjectCanonical: "str" = None,
        trigger: list["TriggerDefinition"] = None,
        condition: list["Condition"] = None,
        input: list["DataRequirement"] = None,
        output: list["DataRequirement"] = None,
        relatedAction: list["RelatedAction"] = None,
        timingDateTime: "str" = None,
        timingAge: "Age" = None,
        timingPeriod: "Period" = None,
        timingDuration: "Duration" = None,
        timingRange: "Range" = None,
        timingTiming: "Timing" = None,
        participant: list["Participant"] = None,
        type: "CodeableConcept" = None,
        groupingBehavior: "str" = None,
        selectionBehavior: "str" = None,
        requiredBehavior: "str" = None,
        precheckBehavior: "str" = None,
        cardinalityBehavior: "str" = None,
        definitionCanonical: "str" = None,
        definitionUri: "str" = None,
        transform: "str" = None,
        dynamicValue: list["DynamicValue"] = None,
        action: list["Action"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.prefix = prefix
        self.title = title
        self.description = description
        self.textEquivalent = textEquivalent
        self.priority = priority
        self.code = code or []
        self.reason = reason or []
        self.documentation = documentation or []
        self.goalId = goalId or []
        self.subjectCodeableConcept = subjectCodeableConcept
        self.subjectReference = subjectReference
        self.subjectCanonical = subjectCanonical
        self.trigger = trigger or []
        self.condition = condition or []
        self.input = input or []
        self.output = output or []
        self.relatedAction = relatedAction or []
        self.timingDateTime = timingDateTime
        self.timingAge = timingAge
        self.timingPeriod = timingPeriod
        self.timingDuration = timingDuration
        self.timingRange = timingRange
        self.timingTiming = timingTiming
        self.participant = participant or []
        self.type = type
        self.groupingBehavior = groupingBehavior
        self.selectionBehavior = selectionBehavior
        self.requiredBehavior = requiredBehavior
        self.precheckBehavior = precheckBehavior
        self.cardinalityBehavior = cardinalityBehavior
        self.definitionCanonical = definitionCanonical
        self.definitionUri = definitionUri
        self.transform = transform
        self.dynamicValue = dynamicValue or []
        self.action = action or []

    @classmethod
    def from_dict(cls, data: dict) -> "PlanDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PlanDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PlanDefinition(DomainResource):
    """This resource allows for the definition of various types of plans as a sharable, consumable, and executable artifact. The resource is general enough to support the description of a broad range of clinical and non-clinical artifacts such as clinical decision support rules, order sets, protocols, and drug quality specifications.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this plan definition, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the plan definition
    :param str version: Business version of the plan definition
    :param str name: Name for this plan definition (computer friendly)
    :param str title: Name for this plan definition (human friendly)
    :param str subtitle: Subordinate title of the plan definition
    :param CodeableConcept type: order-set | clinical-protocol | eca-rule | workflow-definition
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param CodeableConcept subjectCodeableConcept: Type of individual the plan definition is focused on
    :param Reference subjectReference: Type of individual the plan definition is focused on
    :param str subjectCanonical: Type of individual the plan definition is focused on
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the plan definition
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for plan definition (if applicable)
    :param str purpose: Why this plan definition is defined
    :param str usage: Describes the clinical usage of the plan
    :param str copyright: Use and/or publishing restrictions
    :param str approvalDate: When the plan definition was approved by publisher
    :param str lastReviewDate: When the plan definition was last reviewed
    :param Period effectivePeriod: When the plan definition is expected to be used
    :param CodeableConcept topic: E.g. Education, Treatment, Assessment
    :param ContactDetail author: Who authored the content
    :param ContactDetail editor: Who edited the content
    :param ContactDetail reviewer: Who reviewed the content
    :param ContactDetail endorser: Who endorsed the content
    :param RelatedArtifact relatedArtifact: Additional documentation, citations
    :param str library: Logic used by the plan definition
    :param Goal goal: What the plan is trying to accomplish
    :param Action action: Action defined by the plan
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subjectCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "subjectReference": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "topic": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "ContactDetail", "is_contained": False},
        "editor": {"class_name": "ContactDetail", "is_contained": False},
        "reviewer": {"class_name": "ContactDetail", "is_contained": False},
        "endorser": {"class_name": "ContactDetail", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "goal": {"class_name": "Goal", "is_contained": True},
        "action": {"class_name": "Action", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        subtitle: "str" = None,
        type: "CodeableConcept" = None,
        status: "str" = None,
        experimental: "bool" = None,
        subjectCodeableConcept: "CodeableConcept" = None,
        subjectReference: "Reference" = None,
        subjectCanonical: "str" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        usage: "str" = None,
        copyright: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        topic: list["CodeableConcept"] = None,
        author: list["ContactDetail"] = None,
        editor: list["ContactDetail"] = None,
        reviewer: list["ContactDetail"] = None,
        endorser: list["ContactDetail"] = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        library: list["str"] = None,
        goal: list["Goal"] = None,
        action: list["Action"] = None,
    ):

        self.resourceType = "PlanDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.name = name
        self.title = title
        self.subtitle = subtitle
        self.type = type
        self.status = status
        self.experimental = experimental
        self.subjectCodeableConcept = subjectCodeableConcept
        self.subjectReference = subjectReference
        self.subjectCanonical = subjectCanonical
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.usage = usage
        self.copyright = copyright
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.topic = topic or []
        self.author = author or []
        self.editor = editor or []
        self.reviewer = reviewer or []
        self.endorser = endorser or []
        self.relatedArtifact = relatedArtifact or []
        self.library = library or []
        self.goal = goal or []
        self.action = action or []

    @classmethod
    def from_dict(cls, data: dict) -> "PlanDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PlanDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MessageHeader. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.ContactPoint import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Destination(FhirBaseModel):
    """The destination application which the message is intended for.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name of system
    :param Reference target: Particular delivery destination within the destination
    :param str endpoint: Actual destination address or id
    :param Reference receiver: Intended "real-world" recipient for the data
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "target": {"class_name": "Reference", "is_contained": False},
        "receiver": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        target: "Reference" = None,
        endpoint: "str" = None,
        receiver: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.target = target
        self.endpoint = endpoint
        self.receiver = receiver

    @classmethod
    def from_dict(cls, data: dict) -> "MessageHeader":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MessageHeader":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Source(FhirBaseModel):
    """The source application from which this message originated.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name of system
    :param str software: Name of software running the system
    :param str version: Version of software running
    :param ContactPoint contact: Human contact for problems
    :param str endpoint: Actual message source address or id
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contact": {"class_name": "ContactPoint", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        software: "str" = None,
        version: "str" = None,
        contact: "ContactPoint" = None,
        endpoint: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.software = software
        self.version = version
        self.contact = contact
        self.endpoint = endpoint

    @classmethod
    def from_dict(cls, data: dict) -> "MessageHeader":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MessageHeader":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Response(FhirBaseModel):
    """Information about the message that this message is a response to.  Only present if this message is a response.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str identifier: Id of original message
    :param str code: ok | transient-error | fatal-error
    :param Reference details: Specific list of hints/warnings/errors
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "details": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "str" = None,
        code: "str" = None,
        details: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.code = code
        self.details = details

    @classmethod
    def from_dict(cls, data: dict) -> "MessageHeader":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MessageHeader":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MessageHeader(DomainResource):
    """The header for a message exchange that is either requesting or responding to an action.  The reference(s) that are the subject of the action as well as other information related to the action are typically transmitted in a bundle in which the MessageHeader resource instance is the first resource in the bundle.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Coding eventCoding: Code for the event this message represents or link to event definition
    :param str eventUri: Code for the event this message represents or link to event definition
    :param Destination destination: Message destination application(s)
    :param Reference sender: Real world sender of the message
    :param Reference enterer: The source of the data entry
    :param Reference author: The source of the decision
    :param Source source: Message source application
    :param Reference responsible: Final responsibility for event
    :param CodeableConcept reason: Cause of event
    :param Response response: If this is a reply to prior message
    :param Reference focus: The actual content of the message
    :param str definition: Link to the definition for this message
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "eventCoding": {"class_name": "Coding", "is_contained": False},
        "destination": {"class_name": "Destination", "is_contained": True},
        "sender": {"class_name": "Reference", "is_contained": False},
        "enterer": {"class_name": "Reference", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "source": {"class_name": "Source", "is_contained": True},
        "responsible": {"class_name": "Reference", "is_contained": False},
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
        "response": {"class_name": "Response", "is_contained": True},
        "focus": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        eventCoding: "Coding" = None,
        eventUri: "str" = None,
        destination: list["Destination"] = None,
        sender: "Reference" = None,
        enterer: "Reference" = None,
        author: "Reference" = None,
        source: "Source" = None,
        responsible: "Reference" = None,
        reason: "CodeableConcept" = None,
        response: "Response" = None,
        focus: list["Reference"] = None,
        definition: "str" = None,
    ):

        self.resourceType = "MessageHeader"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.eventCoding = eventCoding
        self.eventUri = eventUri
        self.destination = destination or []
        self.sender = sender
        self.enterer = enterer
        self.author = author
        self.source = source
        self.responsible = responsible
        self.reason = reason
        self.response = response
        self.focus = focus or []
        self.definition = definition

    @classmethod
    def from_dict(cls, data: dict) -> "MessageHeader":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MessageHeader":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for EvidenceReport. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Range import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.RelatedArtifact import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.UsageContext import *


class Characteristic(FhirBaseModel):
    """Characteristic.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Characteristic code
    :param Reference valueReference: Characteristic value
    :param CodeableConcept valueCodeableConcept: Characteristic value
    :param bool valueBoolean: Characteristic value
    :param Quantity valueQuantity: Characteristic value
    :param Range valueRange: Characteristic value
    :param bool exclude: Is used to express not the characteristic
    :param Period period: Timeframe for the characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        valueReference: "Reference" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueBoolean: "bool" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
        exclude: "bool" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.valueReference = valueReference
        self.valueCodeableConcept = valueCodeableConcept
        self.valueBoolean = valueBoolean
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange
        self.exclude = exclude
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "EvidenceReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EvidenceReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Subject(FhirBaseModel):
    """Specifies the subject or focus of the report. Answers "What is this report about?".:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Characteristic characteristic: Characteristic
    :param Annotation note: Footnotes and/or explanatory notes
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "characteristic": {"class_name": "Characteristic", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        characteristic: list["Characteristic"] = None,
        note: list["Annotation"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.characteristic = characteristic or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "EvidenceReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EvidenceReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RelatesTo(FhirBaseModel):
    """Relationships that this composition has with other compositions or documents that already exist.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: replaces | amends | appends | transforms | replacedWith | amendedWith | appendedWith | transformedWith
    :param Identifier targetIdentifier: Target of the relationship
    :param Reference targetReference: Target of the relationship
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "targetIdentifier": {"class_name": "Identifier", "is_contained": False},
        "targetReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        targetIdentifier: "Identifier" = None,
        targetReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.targetIdentifier = targetIdentifier
        self.targetReference = targetReference

    @classmethod
    def from_dict(cls, data: dict) -> "EvidenceReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EvidenceReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Section(FhirBaseModel):
    """The root of the sections that make up the composition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str title: Label for section (e.g. for ToC)
    :param CodeableConcept focus: Classification of section (recommended)
    :param Reference focusReference: Classification of section by Resource
    :param Reference author: Who and/or what authored the section
    :param Narrative text: Text summary of the section, for human interpretation
    :param str mode: working | snapshot | changes
    :param CodeableConcept orderedBy: Order of section entries
    :param CodeableConcept entryClassifier: Extensible classifiers as content
    :param Reference entryReference: Reference to resources as content
    :param Quantity entryQuantity: Quantity as content
    :param CodeableConcept emptyReason: Why the section is empty
    :param Section section: Nested Section
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "focus": {"class_name": "CodeableConcept", "is_contained": False},
        "focusReference": {"class_name": "Reference", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "orderedBy": {"class_name": "CodeableConcept", "is_contained": False},
        "entryClassifier": {"class_name": "CodeableConcept", "is_contained": False},
        "entryReference": {"class_name": "Reference", "is_contained": False},
        "entryQuantity": {"class_name": "Quantity", "is_contained": False},
        "emptyReason": {"class_name": "CodeableConcept", "is_contained": False},
        "section": {"class_name": "Section", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        title: "str" = None,
        focus: "CodeableConcept" = None,
        focusReference: "Reference" = None,
        author: list["Reference"] = None,
        text: "Narrative" = None,
        mode: "str" = None,
        orderedBy: "CodeableConcept" = None,
        entryClassifier: list["CodeableConcept"] = None,
        entryReference: list["Reference"] = None,
        entryQuantity: list["Quantity"] = None,
        emptyReason: "CodeableConcept" = None,
        section: list["Section"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.title = title
        self.focus = focus
        self.focusReference = focusReference
        self.author = author or []
        self.text = text
        self.mode = mode
        self.orderedBy = orderedBy
        self.entryClassifier = entryClassifier or []
        self.entryReference = entryReference or []
        self.entryQuantity = entryQuantity or []
        self.emptyReason = emptyReason
        self.section = section or []

    @classmethod
    def from_dict(cls, data: dict) -> "EvidenceReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EvidenceReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class EvidenceReport(DomainResource):
    """The EvidenceReport Resource is a specialized container for a collection of resources and codable concepts, adapted to support compositions of Evidence, EvidenceVariable, and Citation resources and related concepts.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this EvidenceReport, represented as a globally unique URI
    :param str status: draft | active | retired | unknown
    :param UsageContext useContext: The context that the content is intended to support
    :param Identifier identifier: Unique identifier for the evidence report
    :param Identifier relatedIdentifier: Identifiers for articles that may relate to more than one evidence report
    :param Reference citeAsReference: Citation for this report
    :param str citeAsMarkdown: Citation for this report
    :param CodeableConcept type: Kind of report
    :param Annotation note: Used for footnotes and annotations
    :param RelatedArtifact relatedArtifact: Link, description or reference to artifact associated with the report
    :param Subject subject: Focus of the report
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param ContactDetail author: Who authored the content
    :param ContactDetail editor: Who edited the content
    :param ContactDetail reviewer: Who reviewed the content
    :param ContactDetail endorser: Who endorsed the content
    :param RelatesTo relatesTo: Relationships to other compositions/documents
    :param Section section: Composition is broken into sections
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "relatedIdentifier": {"class_name": "Identifier", "is_contained": False},
        "citeAsReference": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "subject": {"class_name": "Subject", "is_contained": True},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "author": {"class_name": "ContactDetail", "is_contained": False},
        "editor": {"class_name": "ContactDetail", "is_contained": False},
        "reviewer": {"class_name": "ContactDetail", "is_contained": False},
        "endorser": {"class_name": "ContactDetail", "is_contained": False},
        "relatesTo": {"class_name": "RelatesTo", "is_contained": True},
        "section": {"class_name": "Section", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        status: "str" = None,
        useContext: list["UsageContext"] = None,
        identifier: list["Identifier"] = None,
        relatedIdentifier: list["Identifier"] = None,
        citeAsReference: "Reference" = None,
        citeAsMarkdown: "str" = None,
        type: "CodeableConcept" = None,
        note: list["Annotation"] = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        subject: "Subject" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        author: list["ContactDetail"] = None,
        editor: list["ContactDetail"] = None,
        reviewer: list["ContactDetail"] = None,
        endorser: list["ContactDetail"] = None,
        relatesTo: list["RelatesTo"] = None,
        section: list["Section"] = None,
    ):

        self.resourceType = "EvidenceReport"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.status = status
        self.useContext = useContext or []
        self.identifier = identifier or []
        self.relatedIdentifier = relatedIdentifier or []
        self.citeAsReference = citeAsReference
        self.citeAsMarkdown = citeAsMarkdown
        self.type = type
        self.note = note or []
        self.relatedArtifact = relatedArtifact or []
        self.subject = subject
        self.publisher = publisher
        self.contact = contact or []
        self.author = author or []
        self.editor = editor or []
        self.reviewer = reviewer or []
        self.endorser = endorser or []
        self.relatesTo = relatesTo or []
        self.section = section or []

    @classmethod
    def from_dict(cls, data: dict) -> "EvidenceReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EvidenceReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SubstanceProtein. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Attachment import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Resource import *


class Subunit(FhirBaseModel):
    """This subclause refers to the description of each subunit constituting the SubstanceProtein. A subunit is a linear sequence of amino acids linked through peptide bonds. The Subunit information shall be provided when the finished SubstanceProtein is a complex of multiple sequences; subunits are not used to delineate domains within a single sequence. Subunits are listed in order of decreasing length; sequences of the same length will be ordered by decreasing molecular weight; subunits that have identical sequences will be repeated multiple times.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int subunit: Index of primary sequences of amino acids linked through peptide bonds in order of decreasing length. Sequences of the same length will be ordered by molecular weight. Subunits that have identical sequences will be repeated and have sequential subscripts
    :param str sequence: The sequence information shall be provided enumerating the amino acids from N- to C-terminal end using standard single-letter amino acid codes. Uppercase shall be used for L-amino acids and lowercase for D-amino acids. Transcribed SubstanceProteins will always be described using the translated sequence; for synthetic peptide containing amino acids that are not represented with a single letter code an X should be used within the sequence. The modified amino acids will be distinguished by their position in the sequence
    :param int length: Length of linear sequences of amino acids contained in the subunit
    :param Attachment sequenceAttachment: The sequence information shall be provided enumerating the amino acids from N- to C-terminal end using standard single-letter amino acid codes. Uppercase shall be used for L-amino acids and lowercase for D-amino acids. Transcribed SubstanceProteins will always be described using the translated sequence; for synthetic peptide containing amino acids that are not represented with a single letter code an X should be used within the sequence. The modified amino acids will be distinguished by their position in the sequence
    :param Identifier nTerminalModificationId: Unique identifier for molecular fragment modification based on the ISO 11238 Substance ID
    :param str nTerminalModification: The name of the fragment modified at the N-terminal of the SubstanceProtein shall be specified
    :param Identifier cTerminalModificationId: Unique identifier for molecular fragment modification based on the ISO 11238 Substance ID
    :param str cTerminalModification: The modification at the C-terminal shall be specified
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "sequenceAttachment": {"class_name": "Attachment", "is_contained": False},
        "nTerminalModificationId": {"class_name": "Identifier", "is_contained": False},
        "cTerminalModificationId": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        subunit: "int" = None,
        sequence: "str" = None,
        length: "int" = None,
        sequenceAttachment: "Attachment" = None,
        nTerminalModificationId: "Identifier" = None,
        nTerminalModification: "str" = None,
        cTerminalModificationId: "Identifier" = None,
        cTerminalModification: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.subunit = subunit
        self.sequence = sequence
        self.length = length
        self.sequenceAttachment = sequenceAttachment
        self.nTerminalModificationId = nTerminalModificationId
        self.nTerminalModification = nTerminalModification
        self.cTerminalModificationId = cTerminalModificationId
        self.cTerminalModification = cTerminalModification

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceProtein":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceProtein":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubstanceProtein(DomainResource):
    """A SubstanceProtein is defined as a single unit of a linear amino acid sequence, or a combination of subunits that are either covalently linked or have a defined invariant stoichiometric relationship. This includes all synthetic, recombinant and purified SubstanceProteins of defined sequence, whether the use is therapeutic or prophylactic. This set of elements will be used to describe albumins, coagulation factors, cytokines, growth factors, peptide/SubstanceProtein hormones, enzymes, toxins, toxoids, recombinant vaccines, and immunomodulators.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param CodeableConcept sequenceType: The SubstanceProtein descriptive elements will only be used when a complete or partial amino acid sequence is available or derivable from a nucleic acid sequence
    :param int numberOfSubunits: Number of linear sequences of amino acids linked through peptide bonds. The number of subunits constituting the SubstanceProtein shall be described. It is possible that the number of subunits can be variable
    :param str disulfideLinkage: The disulphide bond between two cysteine residues either on the same subunit or on two different subunits shall be described. The position of the disulfide bonds in the SubstanceProtein shall be listed in increasing order of subunit number and position within subunit followed by the abbreviation of the amino acids involved. The disulfide linkage positions shall actually contain the amino acid Cysteine at the respective positions
    :param Subunit subunit: This subclause refers to the description of each subunit constituting the SubstanceProtein. A subunit is a linear sequence of amino acids linked through peptide bonds. The Subunit information shall be provided when the finished SubstanceProtein is a complex of multiple sequences; subunits are not used to delineate domains within a single sequence. Subunits are listed in order of decreasing length; sequences of the same length will be ordered by decreasing molecular weight; subunits that have identical sequences will be repeated multiple times
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "sequenceType": {"class_name": "CodeableConcept", "is_contained": False},
        "subunit": {"class_name": "Subunit", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequenceType: "CodeableConcept" = None,
        numberOfSubunits: "int" = None,
        disulfideLinkage: list["str"] = None,
        subunit: list["Subunit"] = None,
    ):

        self.resourceType = "SubstanceProtein"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequenceType = sequenceType
        self.numberOfSubunits = numberOfSubunits
        self.disulfideLinkage = disulfideLinkage or []
        self.subunit = subunit or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceProtein":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceProtein":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Account. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Money import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Coverage(FhirBaseModel):
    """The party(s) that are responsible for covering the payment of this account, and what order should they be applied to the account.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference coverage: The party(s), such as insurances, that may contribute to the payment of this account
    :param int priority: The priority of the coverage in the context of this account
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "coverage": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        coverage: "Reference" = None,
        priority: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.coverage = coverage
        self.priority = priority

    @classmethod
    def from_dict(cls, data: dict) -> "Account":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Account":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Guarantor(FhirBaseModel):
    """The parties responsible for balancing the account if other payment options fall short.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference party: Responsible entity
    :param bool onHold: Credit or other hold applied
    :param Period period: Guarantee account during
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "party": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        party: "Reference" = None,
        onHold: "bool" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.party = party
        self.onHold = onHold
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Account":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Account":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Diagnosis(FhirBaseModel):
    """When using an account for billing a specific Encounter the set of diagnoses that are relevant for billing are stored here on the account where they are able to be sequenced appropriately prior to processing to produce claim(s).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Ranking of the diagnosis (for each type)
    :param CodeableReference condition: The diagnosis relevant to the account
    :param str dateOfDiagnosis: Date of the diagnosis (when coded diagnosis)
    :param CodeableConcept type: Type that this diagnosis has relevant to the account (e.g. admission, billing, discharge …)
    :param bool onAdmission: Diagnosis present on Admission
    :param CodeableConcept packageCode: Package Code specific for billing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "condition": {"class_name": "CodeableReference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "packageCode": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        condition: "CodeableReference" = None,
        dateOfDiagnosis: "str" = None,
        type: list["CodeableConcept"] = None,
        onAdmission: "bool" = None,
        packageCode: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.condition = condition
        self.dateOfDiagnosis = dateOfDiagnosis
        self.type = type or []
        self.onAdmission = onAdmission
        self.packageCode = packageCode or []

    @classmethod
    def from_dict(cls, data: dict) -> "Account":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Account":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Procedure(FhirBaseModel):
    """When using an account for billing a specific Encounter the set of procedures that are relevant for billing are stored here on the account where they are able to be sequenced appropriately prior to processing to produce claim(s).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Ranking of the procedure (for each type)
    :param CodeableReference code: The procedure relevant to the account
    :param str dateOfService: Date of the procedure (when coded procedure)
    :param CodeableConcept type: How this procedure value should be used in charging the account
    :param CodeableConcept packageCode: Package Code specific for billing
    :param Reference device: Any devices that were associated with the procedure
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableReference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "packageCode": {"class_name": "CodeableConcept", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        code: "CodeableReference" = None,
        dateOfService: "str" = None,
        type: list["CodeableConcept"] = None,
        packageCode: list["CodeableConcept"] = None,
        device: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.code = code
        self.dateOfService = dateOfService
        self.type = type or []
        self.packageCode = packageCode or []
        self.device = device or []

    @classmethod
    def from_dict(cls, data: dict) -> "Account":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Account":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RelatedAccount(FhirBaseModel):
    """Other associated accounts related to this account.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept relationship: Relationship of the associated Account
    :param Reference account: Reference to an associated Account
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "relationship": {"class_name": "CodeableConcept", "is_contained": False},
        "account": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        relationship: "CodeableConcept" = None,
        account: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.relationship = relationship
        self.account = account

    @classmethod
    def from_dict(cls, data: dict) -> "Account":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Account":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Balance(FhirBaseModel):
    """The calculated account balances - these are calculated and processed by the finance system.

    The balances with a `term` that is not current are usually generated/updated by an invoicing or similar process.:param str id: Unique id for inter-element referencing
        :param Extension extension: Additional content defined by implementations
        :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
        :param CodeableConcept aggregate: Who is expected to pay this part of the balance
        :param CodeableConcept term: current | 30 | 60 | 90 | 120
        :param bool estimate: Estimated balance
        :param Money amount: Calculated amount
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "aggregate": {"class_name": "CodeableConcept", "is_contained": False},
        "term": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        aggregate: "CodeableConcept" = None,
        term: "CodeableConcept" = None,
        estimate: "bool" = None,
        amount: "Money" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.aggregate = aggregate
        self.term = term
        self.estimate = estimate
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "Account":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Account":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Account(DomainResource):
    """A financial tool for tracking value accrued for a particular purpose.  In the healthcare field, used to track charges for a patient, cost centers, etc.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Account number
    :param str status: active | inactive | entered-in-error | on-hold | unknown
    :param CodeableConcept billingStatus: Tracks the lifecycle of the account through the billing process
    :param CodeableConcept type: E.g. patient, expense, depreciation
    :param str name: Human-readable label
    :param Reference subject: The entity that caused the expenses
    :param Period servicePeriod: Transaction window
    :param Coverage coverage: The party(s) that are responsible for covering the payment of this account, and what order should they be applied to the account
    :param Reference owner: Entity managing the Account
    :param str description: Explanation of purpose/use
    :param Guarantor guarantor: The parties ultimately responsible for balancing the Account
    :param Diagnosis diagnosis: The list of diagnoses relevant to this account
    :param Procedure procedure: The list of procedures relevant to this account
    :param RelatedAccount relatedAccount: Other associated accounts related to this account
    :param CodeableConcept currency: The base or default currency
    :param Balance balance: Calculated account balance(s)
    :param str calculatedAt: Time the balance amount was calculated
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "billingStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "servicePeriod": {"class_name": "Period", "is_contained": False},
        "coverage": {"class_name": "Coverage", "is_contained": True},
        "owner": {"class_name": "Reference", "is_contained": False},
        "guarantor": {"class_name": "Guarantor", "is_contained": True},
        "diagnosis": {"class_name": "Diagnosis", "is_contained": True},
        "procedure": {"class_name": "Procedure", "is_contained": True},
        "relatedAccount": {"class_name": "RelatedAccount", "is_contained": True},
        "currency": {"class_name": "CodeableConcept", "is_contained": False},
        "balance": {"class_name": "Balance", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        billingStatus: "CodeableConcept" = None,
        type: "CodeableConcept" = None,
        name: "str" = None,
        subject: list["Reference"] = None,
        servicePeriod: "Period" = None,
        coverage: list["Coverage"] = None,
        owner: "Reference" = None,
        description: "str" = None,
        guarantor: list["Guarantor"] = None,
        diagnosis: list["Diagnosis"] = None,
        procedure: list["Procedure"] = None,
        relatedAccount: list["RelatedAccount"] = None,
        currency: "CodeableConcept" = None,
        balance: list["Balance"] = None,
        calculatedAt: "str" = None,
    ):

        self.resourceType = "Account"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.billingStatus = billingStatus
        self.type = type
        self.name = name
        self.subject = subject or []
        self.servicePeriod = servicePeriod
        self.coverage = coverage or []
        self.owner = owner
        self.description = description
        self.guarantor = guarantor or []
        self.diagnosis = diagnosis or []
        self.procedure = procedure or []
        self.relatedAccount = relatedAccount or []
        self.currency = currency
        self.balance = balance or []
        self.calculatedAt = calculatedAt

    @classmethod
    def from_dict(cls, data: dict) -> "Account":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Account":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Coding. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.Extension import *


class Coding(FhirBaseModel):
    """Base StructureDefinition for Coding Type: A reference to a code defined by a terminology system.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str system: Identity of the terminology system
    :param str version: Version of the system - if relevant
    :param str code: Symbol in syntax defined by the system
    :param str display: Representation defined by the system
    :param bool userSelected: If this coding was chosen directly by the user
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        system: "str" = None,
        version: "str" = None,
        code: "str" = None,
        display: "str" = None,
        userSelected: "bool" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.system = system
        self.version = version
        self.code = code
        self.display = display
        self.userSelected = userSelected

    @classmethod
    def from_dict(cls, data: dict) -> "Coding":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Coding":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
